import { Pgoutput } from 'pg-logical-replication';
import { ErrorType } from '../common/error';
import { TransactionalLogger } from '../common/logger';
import { OutboxMessage } from '../common/message';
import { ConcurrencyController } from '../concurrency-controller/concurrency-controller';
import { ServiceConfig } from './config';
/**
 * Initiate the outbox/inbox table to listen for WAL messages.
 * @param config The replication connection settings and general service settings
 * @param messageHandler The message handler that handles the outbox/inbox message
 * @param errorHandler A handler that can decide if the WAL message should be acknowledged (permanent_error) or not (transient_error which restarts the logical replication service)
 * @param concurrencyController A controller that ensures some concurrency guarantees.
 * @param logger A logger instance for logging trace up to error logs
 * @param mapAdditionalRows The inbox table requires an additional row to be mapped to the inbox message
 * @returns A function to stop the service
 */
export declare const createService: <T extends OutboxMessage>({ pgReplicationConfig, settings }: ServiceConfig, messageHandler: (message: T) => Promise<void>, errorHandler: (message: T, err: Error) => Promise<ErrorType>, concurrencyController: ConcurrencyController, logger: TransactionalLogger, mapAdditionalRows?: ((row: object) => Record<string, unknown>) | undefined) => [shutdown: {
    (): Promise<void>;
}];
/** Get and map the inbox/outbox message if the WAL log entry is such a message. Otherwise returns undefined. */
declare const getRelevantMessage: <T extends OutboxMessage>(log: Pgoutput.Message, { dbSchema, dbTable }: ServiceConfig['settings'], mapAdditionalRows?: ((row: object) => Record<string, unknown>) | undefined) => T | undefined;
/** Maps the WAL log entry to an outbox or inbox message */
declare const mapMessage: <T extends OutboxMessage>(input: unknown, mapAdditionalRows?: ((row: object) => Record<string, unknown>) | undefined) => T | undefined;
/**
 * This export is _only_ done for unit tests as the createService function is
 * otherwise very hard to unit test. Exports work only for jest tests!
 */
export declare const __only_for_unit_tests__: {
    getRelevantMessage?: typeof getRelevantMessage;
    mapMessage?: typeof mapMessage;
};
export {};
//# sourceMappingURL=replication-service.d.ts.map